C #ADRAY   V1A   8-MAY-73.
C  LAST UPDATE:
C
      SUBROUTINE ADRAY(B,C,A,N)
      DIMENSION   B(N), C(N), A(N)
C
C *PURPOSE.
C	TO ADD VECTORS "B" AND "C" OF LENGTH "N" PUTTING RESULT
C IN "A".
C
C *PARAMETERS:
C
C  B   - REAL  RRAY OF LENGTH "N" OR MORE CONTAINING FIRST VECTOR
C  C   - REAL ARRAY OF LENGTH "N" OR MORE CONTAINING THE SECOND.
C  A   - REAL ARRAY OF LENGTH "N" OR MORE RETURNING RESULT
C  N   - THE LOGICAL LENGTH OF THE VECTORS.
C
C  INPUT PARAMETERS:
C	BB, C, N
C  OUTPUT PARAMETERS:
C	A
C
C *METHOD.
C	STRAIGHTFORWARD.  NOT THAT ANY TWO OF THE ARRAYS
C MAY IN FACT BE EQUIVALENT.
C
C *ACCURACY.
C
C *RESTRICTIONS.
C
C *ERROR CONDITIONS.
C
C *NON STANDARD ROUTINES CALLED.
C
C *TYPICAL TIMES.
C
C *ORIGIN.   M.R.MANNING.
C
C *COMMENTS.
C	THIS ROUTINE WILL OFTEN BE REPLACED BY A MACHINE LANGUAGE
C ONE IN WHICH CASE THE CALLING OVERHEAD MAY BE WORTHWHILE.
C THE FORTRAN VERSION IS MAINLY FOR PORTABILITY AND AS A
C LANGUAGE EXTENDING ROUTINE.
C
C #END.
C
      DO 10 I=1, N
10    A(I)= B(I) + C(I)
      RETURN
      END
��������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������������